@@ -26,6 +26,8 @@
 #include "haze-yahoo-account.h"
 #include "haze-aim-account.h"
 #include "haze-msn-account.h"
+#include "haze-groupwise-account.h"
+#include "haze-steam-account.h"
 
 #include <KPluginFactory>
 
@@ -41,6 +43,8 @@ HazeAccountUiPlugin::HazeAccountUiPlugin(QObject *parent, const QVariantList &)
     registerProvidedProtocol(QLatin1String("haze"), QLatin1String("yahoo"));
     registerProvidedProtocol(QLatin1String("haze"), QLatin1String("aim"));
     registerProvidedProtocol(QLatin1String("haze"), QLatin1String("msn"));
+    registerProvidedProtocol(QLatin1String("haze"), QLatin1String("groupwise"));
+    registerProvidedProtocol(QLatin1String("haze"), QLatin1String("steam-mobile"));
 }
 
 HazeAccountUiPlugin::~HazeAccountUiPlugin()
@@ -64,7 +68,11 @@ AbstractAccountUi* HazeAccountUiPlugin::accountUi(const QString &connectionManag
             return new HazeAimAccount;
         } else if (protocol == QLatin1String("msn")) {
             return new HazeMsnAccountUi;
-        }
+        } else if (protocol == QLatin1String("groupwise")) {
+            return new HazeGroupWiseAccountUi;
+        } else if (protocol == QLatin1String("steam-mobile")) {
+            return new HazeSteamAccountUi;
+	}
     }
 
     return 0;
